# Theorist Overview

AutoRA consists of a set of techniques designed to automate the construction of interpretable models of human brain function and behavior. To approach this problem, we can consider computational models as small, interpretable [computation graphs](https://medium.com/tebs-lab/deep-neural-networks-as-computational-graphs-867fcaa56c9) (see also [Musslick, 2021](https://arxiv.org/abs/2103.13939)). A computation graph can take experiment parameters as input (e.g. the brightness of a visual stimulus) and can transform this input through a combination of functions to produce observable dependent measures as output (e.g. the probability that a participant can detect the stimulus). AutoRA provides adaptations of neural architecture search and symbolic regression to automate the discovery of such models.
